bwaaa


<!-- DOESN'T work:

- [content/supplemental/impact_demagnetization.md](content/supplemental/impact_demagnetization.md)
- [/content/supplemental/impact_demagnetization.md](/content/supplemental/impact_demagnetization.md)
- [content/supplemental/impact_demagnetization](content/supplemental/impact_demagnetization)


DOES work, but BAD practice (gives warning in console when live loading):

- [/content/supplemental/impact_demagnetization](/content/supplemental/impact_demagnetization)
- [impact_demagnetization](impact_demagnetization) -->


DOES work, GOOD practice:

- [impact_demagnetization.md](impact_demagnetization.md)
